.. change::
    :tags: bug, tests
    :tickets: 9002
    :versions: 2.0.0rc1

    Added new exclusion rule for third party dialects called
    ``unusual_column_name_characters``, which can be "closed" for third party
    dialects that don't support column names with unusual characters such as
    dots, slashes, or percent signs in them, even if the name is properly
    quoted.

